<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.System.Profile.SystemManufacturers

Windows Runtime (WinRT) APIs for for the `Windows.System.Profile.SystemManufacturers` namespace.

This package provides the `winrt.windows.system.profile.systemmanufacturers` module.
